@@ -35,9 +35,7 @@
 
 #include <QLockFile>
 #include <QStandardPaths>
-#include <memory> // auto_ptr
 #include <qplatformdefs.h>
-#include <time.h>
 
 static const char *s_cSycocaPath = nullptr;
 
@@ -405,7 +403,7 @@ bool KBuildSycoca::recreate(bool incremental)
     d->m_mimeTypeFactory = buildMimeTypeFactory;
     m_buildServiceGroupFactory = new KBuildServiceGroupFactory(this);
     d->m_serviceGroupFactory = m_buildServiceGroupFactory;
-    d->m_serviceFactory = new KBuildServiceFactory(buildMimeTypeFactory, m_buildServiceGroupFactory);
+    d->m_serviceFactory = new KBuildServiceFactory(buildMimeTypeFactory);
 
     if (build()) { // Parse dirs
         save(str); // Save database
@@ -422,7 +420,12 @@ bool KBuildSycoca::recreate(bool incremental)
             const int uid = qEnvironmentVariableIntValue("SUDO_UID");
             const int gid = qEnvironmentVariableIntValue("SUDO_GID");
             if (uid && gid) {
-                fchown(database.handle(), uid, gid);
+                int ret;
+                ret = fchown(database.handle(), uid, gid);
+                if (ret < 0) {
+                    qCWarning(SYCOCA) << "ERROR changing ownership of database" << database.fileName() << strerror(errno);
+                    return false;
+                }
             }
         }
 #endif
